@@ -13,15 +13,14 @@
 
 /* Static helper functions */
 
-static node_t* alloc_node();
+static node_t *alloc_node(void);
 static int eval_gt_node(node_t *node, fieldset_t *fields);
 static int eval_lt_node(node_t *node, fieldset_t *fields);
 static int eval_eq_node(node_t *node, fieldset_t *fields);
 static int eval_lt_eq_node(node_t *node, fieldset_t *fields);
 static int eval_gt_eq_node(node_t *node, fieldset_t *fields);
 
-
-static node_t* alloc_node()
+static node_t *alloc_node(void)
 {
 	node_t *node = xmalloc(sizeof(node_t));
 	return node;
@@ -49,17 +48,18 @@ static int eval_eq_node(node_t *node, fieldset_t *fields)
 	int index = node->left_child->value.field.index;
 	char *expected, *actual;
 	switch (literal->type) {
-		case STRING:
-			expected = literal->value.string_literal;
-			actual = fs_get_string_by_index(fields, index);
-			return (strcmp(expected, actual) == 0);
-			break;
-		case INT:
-			return (fs_get_uint64_by_index(fields, index) == literal->value.int_literal);
-			break;
-		default:
-			printf("wat\n");
-			break;
+	case STRING:
+		expected = literal->value.string_literal;
+		actual = fs_get_string_by_index(fields, index);
+		return (strcmp(expected, actual) == 0);
+		break;
+	case INT:
+		return (fs_get_uint64_by_index(fields, index) ==
+			literal->value.int_literal);
+		break;
+	default:
+		printf("wat\n");
+		break;
 	}
 	return 0;
 }
@@ -74,18 +74,17 @@ static int eval_gt_eq_node(node_t *node, fieldset_t *fields)
 	return !(eval_lt_node(node, fields));
 }
 
-
 /* Exposed functions */
 
-node_t* make_op_node(enum operation op)
+node_t *make_op_node(enum operation op)
 {
-	node_t* node = alloc_node();
+	node_t *node = alloc_node();
 	node->type = OP;
 	node->value.op = op;
 	return node;
 }
 
-node_t* make_field_node(char *fieldname)
+node_t *make_field_node(char *fieldname)
 {
 	node_t *node = alloc_node();
 	node->type = FIELD;
@@ -93,7 +92,7 @@ node_t* make_field_node(char *fieldname)
 	return node;
 }
 
-node_t* make_string_node(char *literal)
+node_t *make_string_node(char *literal)
 {
 	node_t *node = alloc_node();
 	node->type = STRING;
@@ -101,7 +100,7 @@ node_t* make_string_node(char *literal)
 	return node;
 }
 
-node_t* make_int_node(int literal)
+node_t *make_int_node(int literal)
 {
 	node_t *node = alloc_node();
 	node->type = INT;
@@ -111,7 +110,8 @@ node_t* make_int_node(int literal)
 
 int evaluate_expression(node_t *root, fieldset_t *fields)
 {
-	if (!root) return 1;
+	if (!root)
+		return 1;
 	switch (root->type) { /* XXX Not sure if runs */
 	case FIELD:
 	case STRING:
@@ -134,35 +134,36 @@ int evaluate_expression(node_t *root, fieldset_t *fields)
 	case GT_EQ:
 		return eval_gt_eq_node(root, fields);
 	case AND:
-		return (evaluate_expression(root->left_child, fields)
-			&& evaluate_expression(root->right_child, fields));
+		return (evaluate_expression(root->left_child, fields) &&
+			evaluate_expression(root->right_child, fields));
 	case OR:
-		return (evaluate_expression(root->left_child, fields)
-			|| evaluate_expression(root->right_child, fields));
+		return (evaluate_expression(root->left_child, fields) ||
+			evaluate_expression(root->right_child, fields));
 	}
 	return 0;
 }
 
 void print_expression(node_t *root)
 {
-	if (!root) return;
+	if (!root)
+		return;
 	printf("%s", "( ");
 	print_expression(root->left_child);
 	switch (root->type) {
-		case OP:
-			printf(" %i ", root->value.op);
-			break;
-		case FIELD:
-			printf(" (%s", root->value.field.fieldname);
-			break;
-		case STRING:
-			printf("%s) ", root->value.string_literal);
-			break;
-		case INT:
-			printf(" %llu) ", (long long unsigned) root->value.int_literal);
-			break;
-		default:
-			break;
+	case OP:
+		printf(" %i ", root->value.op);
+		break;
+	case FIELD:
+		printf(" (%s", root->value.field.fieldname);
+		break;
+	case STRING:
+		printf("%s) ", root->value.string_literal);
+		break;
+	case INT:
+		printf(" %llu) ", (long long unsigned)root->value.int_literal);
+		break;
+	default:
+		break;
 	}
 	print_expression(root->right_child);
 	printf("%s", " )");
