@@ -6,9 +6,13 @@
  * of the License at http://www.apache.org/licenses/LICENSE-2.0
  */
 
+#include <pthread.h>
+#include "iterator.h"
+
 #ifndef MONITOR_H
 #define MONITOR_H
 
-void monitor_run();
+void monitor_run(iterator_t *it, pthread_mutex_t *lock);
+void monitor_init(void);
 
 #endif
