@@ -12,20 +12,23 @@
 #include "../state.h"
 #include "../fieldset.h"
 
+#define NO_DYNAMIC_SUPPORT 0
+#define DYNAMIC_SUPPORT 1
+
 // called at scanner initialization
-typedef int (*output_init_cb)(struct state_conf *, char **fields, int fieldslen);
+typedef int (*output_init_cb)(struct state_conf *, const char **fields,
+			      int fieldslen);
 
 // called on packet receipt
 typedef int (*output_packet_cb)(fieldset_t *fs);
 
 // called periodically during the scan
-typedef int (*output_update_cb)(struct state_conf*,
-		struct state_send*, struct state_recv*);
+typedef int (*output_update_cb)(struct state_conf *, struct state_send *,
+				struct state_recv *);
 
 typedef struct output_module {
 	const char *name;
-	int filter_duplicates;
-	int filter_unsuccessful;
+	int supports_dynamic_output;
 	unsigned update_interval;
 	output_init_cb init;
 	output_update_cb start;
@@ -35,7 +38,7 @@ typedef struct output_module {
 	const char *helptext;
 } output_module_t;
 
-output_module_t* get_output_module_by_name(const char*);
+output_module_t *get_output_module_by_name(const char *);
 
 void print_output_modules(void);
 
