@@ -6,12 +6,12 @@
  * of the License at http://www.apache.org/licenses/LICENSE-2.0
  */
 
-#ifndef RECV_H
-#define RECV_H
+#ifndef ZMAP_RECV_H
+#define ZMAP_RECV_H
 
 #include <pthread.h>
 
-int recv_update_pcap_stats(void);
+int recv_update_stats(void);
 int recv_run(pthread_mutex_t *recv_ready_mutex);
 
-#endif //_RECV_H
+#endif /* ZMP_RECV_H */
