@@ -11,9 +11,9 @@
 
 #define VALIDATE_BYTES 16
 
-void validate_init();
+void validate_init(void);
 void validate_gen(const uint32_t src, const uint32_t dst,
-		  uint8_t output[VALIDATE_BYTES]);
+		  const uint16_t dst_port, uint8_t output[VALIDATE_BYTES]);
 void validate_gen_ex(const uint32_t input0, const uint32_t input1,
 		     const uint32_t input2, const uint32_t input3,
 		     uint8_t output[VALIDATE_BYTES]);
